==> org-lsst-ccs-localdb-jar-3.0.11-sources.jar: org/lsst/ccs/localdb/statusdb/server/AlertEvent.java <==
package org.lsst.ccs.localdb.statusdb.server;

import java.io.Serializable;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import org.lsst.ccs.bus.states.AlertState;

/**
 * Describes an alert event such as a raised alert.
 * @author LSST CCS Team
 */
@XmlRootElement(name = "alertevent")
public class AlertEvent implements Serializable {
    private static final long serialVersionUID = 1674716707019828119L;
    
    /**
     * The alertId of the corresponding alertdesc.
     */
    private String alertId;
    
    private long time;
    
    private AlertState severity;
    
    private String cause;
    
    private boolean cleared;
    
    public AlertEvent() {
        
    }
    
    public AlertEvent(String alertId, long time, AlertState severity, String cause) {
        this.alertId = alertId;
        this.time = time;
        this.severity = severity;
        this.cause = cause;
    }

    @XmlElement(name="alertid")
    public String getAlertId() {
        return alertId;
    }

    @XmlElement(name="time")
    public long getTime() {
        return time;
    }

    @XmlElement(name="severity")
    public AlertState getSeverity() {
        return severity;
    }

    @XmlElement(name="cause")
    public String getCause() {
        return cause;
    }

    @XmlElement(name="cleared")
    public boolean isCleared() {
        return cleared;
    }
    
    public void setCleared(boolean cleared) {
        this.cleared = cleared;
    }
    
    @XmlRootElement(name = "alertevents")
    public static class AlertEventList {
        
        @XmlElement(name="alertevent")
        private List<AlertEvent> list;
        
        public AlertEventList() {
            
        }
        
        public AlertEventList(List<AlertEvent> l) {
            this.list = l;
        }
        
        
    }
    
}

==> org-lsst-ccs-localdb-jar-4.1.20-sources.jar: org/lsst/ccs/localdb/statusdb/server/AlertEvent.java <==
package org.lsst.ccs.localdb.statusdb.server;

import java.io.Serializable;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import org.lsst.ccs.bus.states.AlertState;

/**
 * Describes an alert event such as a raised alert.
 * @author LSST CCS Team
 */
@XmlRootElement(name = "alertevent")
public class AlertEvent implements Serializable {
    private static final long serialVersionUID = 1674716707019828119L;
    
    /**
     * The alertId of the corresponding alertdesc.
     */
    private String alertId;
    
    private long time;
    
    private AlertState severity;
    
    private String cause;
    
    private boolean cleared;
    
    public AlertEvent() {
        
    }
    
    public AlertEvent(String alertId, long time, AlertState severity, String cause) {
        this.alertId = alertId;
        this.time = time;
        this.severity = severity;
        this.cause = cause;
    }

    @XmlElement(name="alertid")
    public String getAlertId() {
        return alertId;
    }

    @XmlElement(name="time")
    public long getTime() {
        return time;
    }

    @XmlElement(name="severity")
    public AlertState getSeverity() {
        return severity;
    }

    @XmlElement(name="cause")
    public String getCause() {
        return cause;
    }

    @XmlElement(name="cleared")
    public boolean isCleared() {
        return cleared;
    }
    
    public void setCleared(boolean cleared) {
        this.cleared = cleared;
    }
    
    @XmlRootElement(name = "alertevents")
    public static class AlertEventList {
        
        @XmlElement(name="alertevent")
        public List<AlertEvent> list;
        
        public AlertEventList() {
            
        }
        
        public AlertEventList(List<AlertEvent> l) {
            this.list = l;
        }
        
        
    }
    
}
